@@ -6,11 +6,12 @@ from pyorient.exceptions import PyOrientBadMethodCallException
 from .base import BaseMessage
 from .connection import ConnectMessage
 from ..constants import DB_OPEN_OP, DB_TYPE_DOCUMENT, DB_COUNT_RECORDS_OP, FIELD_BYTE, FIELD_INT, \
-    FIELD_SHORT, FIELD_STRING, FIELD_STRINGS, FIELD_BOOLEAN, NAME, SUPPORTED_PROTOCOL, \
+    FIELD_SHORT, FIELD_STRING, FIELD_STRINGS, FIELD_BYTES, FIELD_BOOLEAN, NAME, SUPPORTED_PROTOCOL, \
     VERSION, DB_TYPES, SERIALIZATION_SERIAL_BIN, SERIALIZATION_TYPES, \
     DB_CLOSE_OP, DB_EXIST_OP, STORAGE_TYPE_PLOCAL, STORAGE_TYPE_LOCAL, DB_CREATE_OP, \
-    DB_DROP_OP, DB_RELOAD_OP, DB_SIZE_OP, STORAGE_TYPES, FIELD_LONG
+    DB_DROP_OP, DB_RELOAD_OP, DB_SIZE_OP, DB_LIST_OP, STORAGE_TYPES, FIELD_LONG
 from ..utils import need_connected, need_db_opened
+from ..serialization import OrientRecord, ORecordDecoder
 
 #
 # DB OPEN
@@ -54,16 +55,6 @@ class DbOpenMessage(BaseMessage):
 
         self._append( ( FIELD_BYTE, DB_OPEN_OP ) )
 
-    def _perform_connection(self):
-        # try to connect, we inherited BaseMessage
-        conn_message = ConnectMessage( self._orientSocket )
-        # set session id and protocol
-        self._session_id = conn_message\
-            .prepare( ( self._user, self._pass, self._client_id ) )\
-            .send().fetch_response()
-        # now, self._session_id and _orient_socket.session_id are updated
-        self.get_protocol()
-
     def prepare(self, params=None ):
 
         if isinstance( params, tuple ) or isinstance( params, list ):
@@ -82,36 +73,40 @@ class DbOpenMessage(BaseMessage):
                 # Use default for non existent indexes
                 pass
 
-        # if session id is -1, so we aren't connected
-        # because ConnectMessage set the client id
-        # this block of code check for session because this class
-        # can be initialized directly from orient socket
-        if self._orientSocket.session_id < 0:
-            self._perform_connection()
-
-        if self.get_protocol() > 21:
-            connect_string = (FIELD_STRINGS, [self._client_id,
-                                              self._serialization_type,
-                                              self._db_name,
-                                              self._db_type,
-                                              self._user, self._pass])
-        else:
-            connect_string = (FIELD_STRINGS, [self._client_id,
-                                              self._db_name, self._db_type,
-                                              self._user, self._pass])
-
         self._append( ( FIELD_STRINGS, [NAME, VERSION] ) )
         self._append( ( FIELD_SHORT, SUPPORTED_PROTOCOL ) )
-        self._append( connect_string )
+        self._append( ( FIELD_STRING, self._client_id ) )
+
+        if self.get_protocol() > 21:
+            self._append( ( FIELD_STRING, self._serialization_type ) )
+
+        if self.get_protocol() > 26:
+            self._append( ( FIELD_BOOLEAN, False ) )
+
+        self._append( ( FIELD_STRING, self._db_name ) )
+        self._append( ( FIELD_STRING, self._db_type ) )
+
+        self._append( ( FIELD_STRING, self._user ) )
+        self._append( ( FIELD_STRING, self._pass ) )
 
         return super( DbOpenMessage, self ).prepare()
 
     def fetch_response(self):
         self._append( FIELD_INT )  # session_id
+        if self.get_protocol() > 26:
+            self._append( FIELD_STRING )  # token # if FALSE: Placeholder
+
         self._append( FIELD_SHORT )  # cluster_num
 
-        self._session_id, cluster_num = \
-            super( DbOpenMessage, self ).fetch_response()
+        result = super( DbOpenMessage, self ).fetch_response()
+        if self.get_protocol() > 26:
+            self._session_id, self._token, cluster_num = result
+            self._update_token()
+        else:
+            self._session_id, cluster_num = result
+
+        # IMPORTANT needed to pass the id to other messages
+        self._update_socket_id()
 
         clusters = []
         try:
@@ -134,7 +129,7 @@ class DbOpenMessage(BaseMessage):
             # Should not happen because of protocol check
             pass
 
-        self._append( FIELD_INT )  # cluster config string ( -1 )
+        self._append( FIELD_STRING )  # cluster config string ( -1 )
         self._append( FIELD_STRING )  # cluster release
 
         response = super( DbOpenMessage, self ).fetch_response(True)
@@ -528,4 +523,36 @@ class DbSizeMessage(BaseMessage):
 
     def fetch_response(self):
         self._append( FIELD_LONG )
-        return super( DbSizeMessage, self ).fetch_response()[0]
\ No newline at end of file
+        return super( DbSizeMessage, self ).fetch_response()[0]
+
+
+#
+# DB List
+#
+# Asks for the size of a database in the OrientDB Server instance.
+#
+# Request: empty
+# Response: (size:long)
+#
+class DbListMessage(BaseMessage):
+
+    def __init__(self, _orient_socket ):
+        super( DbListMessage, self ).__init__(_orient_socket)
+
+        # order matters
+        self._append( ( FIELD_BYTE, DB_LIST_OP ) )
+
+    @need_connected
+    def prepare(self, params=None):
+        return super( DbListMessage, self ).prepare()
+
+    def fetch_response(self):
+        self._append( FIELD_BYTES )
+        __record = super( DbListMessage, self ).fetch_response()[0]
+        # bug in orientdb csv serialization in snapshot 2.0,
+        # strip trailing spaces
+        _record = ORecordDecoder( __record.rstrip() )
+
+        return OrientRecord(
+            _record.data
+        )
