@@ -86,7 +86,7 @@ class RawMessages_5_TestCase(unittest.TestCase):
 
     def test_transaction(self):
         connection = OrientSocket( "localhost", 2424 )
-        session_id = ( ConnectMessage( connection ) ).prepare( ("admin", "admin") )\
+        session_id = ( ConnectMessage( connection ) ).prepare( ("root", "root") )\
             .send().fetch_response()
 
         db_name = "my_little_test"
@@ -171,6 +171,9 @@ class RawMessages_5_TestCase(unittest.TestCase):
         assert res["#3:3"].vacanza == 'mare'
         assert res["#3:4"].vacanza == 'lago'
 
+        sid = ( ConnectMessage( connection ) ).prepare( ("root", "root") )\
+            .send().fetch_response()
+
         # # at the end drop the test database
         ( DbDropMessage( connection ) ).prepare([db_name, STORAGE_TYPE_MEMORY]) \
             .send().fetch_response()
